@@ -7,7 +7,7 @@ CC  THE FOLLOWING VECTORS AND MATRICES MUST BE DIMENSIONED IN THE
 CC  MAIN PROGRAM :
 CC   X(NN,JPP),DISV(1+NN*(NN-1)/2)
 CC   JTMD(JPP),VALMD(JPP)
-CC   CHARACTER VTYPE(JPP)
+CC   INTEGER (was CHARACTER) VTYPE(JPP)
 CC  WHERE :
 CC          NN = NUMBER OF OBJECTS
 CC          JPP = NUMBER OF VARIABLES USED FOR THE CALCULATIONS
@@ -15,16 +15,16 @@ CC
       IMPLICIT DOUBLE PRECISION(A-H,O-Z)
 
       DIMENSION X(NN,JPP),DISV(1+NN*(NN-1)/2),VALMD(JPP),JTMD(JPP)
-      CHARACTER JDAT,VTYPE(JPP)
+      INTEGER JDAT,VTYPE(JPP)
 
 CC
 CC    VTYPE(J) IS THE TYPE OF VARIABLE J:
-CC        = A FOR AN ASYMMETRIC BINARY VARIABLE
-CC        = S FOR A SYMMETRIC BINARY VARIABLE
-CC        = N FOR A NOMINAL VARIABLE
-CC        = O FOR AN ORDINAL VARIABLE
-CC        = I FOR AN INTERVAL VARIABLE (ADDITIVE)
-CC        = T FOR A RATIO VARIABLE
+CC        = 1(A) FOR AN ASYMMETRIC BINARY VARIABLE
+CC        = 2(S) FOR A SYMMETRIC BINARY VARIABLE
+CC        = 3(N) FOR A NOMINAL VARIABLE
+CC        = 4(O) FOR AN ORDINAL VARIABLE
+CC        = 5(I) FOR AN INTERVAL VARIABLE (ADDITIVE)
+CC        = 6(T) FOR A RATIO VARIABLE
 CC
 CC    VECTOR JTMD IS ONLY READ IF THERE ARE MISSING VALUES
 CC JTMD(J) = 0 IF VARIABLE J IS BINARY
@@ -32,7 +32,7 @@ CC         =-1 IF VARIABLE J IS NOT BINARY AND HAS MISSING VALUES
 CC         =+1 IF VARIABLE J IS NOT BINARY AND HAS NO MISSING VALUES
 CC
 
-  200 IF(JDAT.EQ.'2')GO TO 500
+  200 IF(JDAT.EQ.2)GO TO 500
 
 CC
 CC   CALCULATION OF THE DISSIMILARITIES
@@ -47,19 +47,19 @@ CC
       PPA=0.
       DLK=0.
       DO 420 J=1,JPP
-      IF(VTYPE(J).EQ.'A'.OR.VTYPE(J).EQ.'S')GO TO 410
+      IF(VTYPE(J).EQ.1.OR.VTYPE(J).EQ.2)GO TO 410
       IF(JTMD(J).GE.0)GO TO 405
       IF(X(L,J).EQ.VALMD(J))GO TO 420
       IF(X(K,J).EQ.VALMD(J))GO TO 420
   405 PPA=PPA+1.
-      IF(VTYPE(J).EQ.'N'.AND.X(L,J).NE.X(K,J))DLK=DLK+1.
-      IF(VTYPE(J).EQ.'A'.OR.VTYPE(J).EQ.'S'.OR.VTYPE(J).EQ.'N')
+      IF(VTYPE(J).EQ.3.AND.X(L,J).NE.X(K,J))DLK=DLK+1.
+      IF(VTYPE(J).EQ.1.OR.VTYPE(J).EQ.2.OR.VTYPE(J).EQ.3)
      F GO TO 420
       DLK=DLK+DABS(X(L,J)-X(K,J))
       GO TO 420
   410 IF(X(L,J).NE.0..AND.X(L,J).NE.1.)GO TO 420
       IF(X(K,J).NE.0..AND.X(K,J).NE.1.)GO TO 420
-      IF(VTYPE(J).EQ.'S'.OR.X(L,J).NE.0.OR.X(K,J).NE.0)PPA=PPA+1.
+      IF(VTYPE(J).EQ.2.OR.X(L,J).NE.0.OR.X(K,J).NE.0)PPA=PPA+1.
       IF(X(L,J).NE.X(K,J))DLK=DLK+1.
   420 CONTINUE
       IF(PPA.GT.0.5)GO TO 430
